OC.L10N.register(
    "federatedfilesharing",
    {
    "Do you want to add the remote share {name} from {owner}@{remote}?" : "Vill du lägga till extern delning {name} från {owner}@{remote}?",
    "Remote share" : "Extern delning",
    "Remote share password" : "Lösenord för extern delning",
    "Cancel" : "Avbryt",
    "Add remote share" : "Lägg till extern delning",
    "Invalid Federated Cloud ID" : "Ogiltig Federerad Moln-ID",
    "Server to server sharing is not enabled on this server" : "Server-till-server-delning är inte aktiverat på denna server",
    "Couldn't establish a federated share." : "Kunde inte lägga till en federerad utdelning",
    "Couldn't establish a federated share, maybe the password was wrong." : "Kunde inte lägga till en federerad utdelning, lösenordet kanske var felaktigt.",
    "Federated Share request sent, you will receive an invitation. Check your notifications." : "Federerad delningsförfrågan skickades, du kommer att få en inbjudan. Kontrollera dina aviseringar.",
    "Couldn't establish a federated share, it looks like the server to federate with is too old (Nextcloud <= 9)." : "Kunde inte etablera federerad delning, det verkar som servern att federera med är för gammal (Nextcloud <= 9).",
    "It is not allowed to send federated group shares from this server." : "Det är inte tillåtet att skicka federerade gruppdelningar från den här servern.",
    "Sharing %1$s failed, because this item is already shared with user %2$s" : "Delning av %1$s misslyckades eftersom detta redan är delat med användaren %2$s",
    "Not allowed to create a federated share with the same user" : "Inte tillåtet att skapa en federerad delning med samma användare",
    "Federated shares require read permissions" : "Federerade delningar kräver läsbehörighet",
    "File is already shared with %s" : "Filen är redan delad med %s",
    "Sharing %1$s failed, could not find %2$s, maybe the server is currently unreachable or uses a self-signed certificate." : "Delning %1$s misslyckades. Kunde inte hitta %2$s, kanske är servern inte tillgänglig eller så används ett självsignerat certifikat.",
    "Could not find share" : "Kunde inte hitta delning",
    "Federated sharing" : "Federerad delning",
    "You received {share} as a remote share from {user} (on behalf of {behalf})" : "Du tog emot {share} som en extern delning {user} (på uppdrag av {behalf})",
    "You received {share} as a remote share from {user}" : "Du tog emot {share} som en extern delning från {user}",
    "Accept" : "Acceptera",
    "Decline" : "Neka",
    "Federated Cloud Sharing" : "Federerad Moln-delning",
    "Sharing" : "Dela",
    "Federated file sharing" : "Federerad fildelning",
    "Provide federated file sharing across servers" : "Erbjuder federerad fildelning mellan servrar",
    "Adjust how people can share between servers. This includes shares between users on this server as well if they are using federated sharing." : "Anpassa hur användare kan dela mellan servrar. Detta inkluderar även delningar mellan användare på denna server ifall de använder federerad delning.",
    "Allow users on this server to send shares to other servers (this option also allows WebDAV access to public shares)" : "Tillåt användare på denna server att skicka delningar till andra servrar (denna inställning ger också WebDAV-tillgång till offentliga delningar)",
    "Allow users on this server to receive shares from other servers" : "Tillåt användare på denna servern att ta emot utdelningar från andra servrar",
    "Allow users on this server to send shares to groups on other servers" : "Tillåt användare på denna server att skicka delningar till grupper på andra servrar",
    "Allow users on this server to receive group shares from other servers" : "Tillåt användare på denna servern att ta emot gruppdelningar från andra servrar",
    "Search global and public address book for users" : "Sök global och offentlig adressbok för användare",
    "Allow users to publish their data to a global and public address book" : "Tillåt användare att publicera deras data till en global och publik adressbok",
    "Unable to update federated files sharing config" : "Kunde inte uppdatera konfigurationen för federerad fildelning",
    "Federated Cloud" : "Federerat moln",
    "You can share with anyone who uses a Nextcloud server or other Open Cloud Mesh (OCM) compatible servers and services! Just put their Federated Cloud ID in the share dialog. It looks like person@cloud.example.com" : "Du kan dela med alla som använder en Nextcloud-server eller andra Open Cloud Mesh (OCM) -kompatibla servrar och tjänster! Anger bara sitt federerade moln-ID i delningsrutan. Det ser ut som person@cloud.example.com",
    "Your Federated Cloud ID:" : "Ditt federerade moln-ID:",
    "Share it so your friends can share files with you:" : "Dela det så att dina vänner kan dela filer med dig:",
    "Facebook" : "Facebook",
    "Twitter" : "Twitter",
    "Diaspora" : "Diaspora",
    "Add to your website" : "Lägg till på din hemsida",
    "Share with me via Nextcloud" : "Dela med mig via Nextcloud",
    "HTML Code:" : "HTML Kod:",
    "Share with me through my #Nextcloud Federated Cloud ID, see {url}" : "Dela med mig genom mitt #Nextcloud federerade moln-ID, se {url}",
    "Share with me through my #Nextcloud Federated Cloud ID" : "Dela med mig genom mitt #Nextcloud federerade moln-ID",
    "Cloud ID copied to the clipboard" : "Moln-ID kopierades till urklippet",
    "Copy to clipboard" : "Kopiera till urklipp",
    "Clipboard is not available" : "Urklipp är inte tillgängligt",
    "Copied!" : "Kopierad!",
    "Copy" : "Kopiera",
    "Not supported!" : "Stöds inte!",
    "Press ⌘-C to copy." : "Tryck ⌘-C för att kopiera.",
    "Press Ctrl-C to copy." : "Tryck Ctrl-C för att kopiera.",
    "You received \"%3$s\" as a remote share from %4$s (%1$s) (on behalf of %5$s (%2$s))" : "Du tog emot \"%3$s\" som en extern delning från %4$s (%1$s) (via %5$s (%2$s))",
    "You received \"%3$s\" as a remote share from %4$s (%1$s)" : "Du tog emot \"%3$s\" som en extern delning från %4$s (%1$s)",
    "Share with me through my #Nextcloud Federated Cloud ID, see %s" : "Dela med mig genom mitt #Nextcloud federerade moln-ID, se %s",
    "Open documentation" : "Öppna dokumentationen"
},
"nplurals=2; plural=(n != 1);");
